@@ -1,13 +1,12 @@
 package Tie::DeepTied;
-require Tie::Hash;
-
-# $Id: DeepTied.pm 1049 2003-12-08 21:10:33Z jonasbn $
 
 use strict qw(vars subs);
 use warnings;
 use vars qw(@ISA $VERSION);
 
-$VERSION = '1.08';
+require Tie::Hash;
+
+$VERSION = '1.09';
 @ISA = qw(Tie::Hash);
 
 sub TIEHASH {
@@ -77,3 +76,46 @@ sub NEXTKEY {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Tie::DeepTied
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 SUBROUTINES/METHODS
+
+=head2 TIEHASH
+
+=head2 STORE
+
+=head2 FETCH
+
+=head2 DELETE
+
+=head2 EXISTS
+
+=head2 CLEAR
+
+=head2 FIRSTKEY
+
+=head2 NEXTKEY
+
+=head1 AUTHOR
+
+Ariel Brosh, schop@cpan.org.
+B<Tie::Cache> was written by Joshua Chamas, chamas@alumni.stanford.org
+
+=head1 SEE ALSO
+
+perl(1), L<Tie::Cache>.
+
+=head1 COPYRIGHT
+
+Tie::Collection is part of the HTPL package. See L<HTML::HTPL>
+
+=cut
