@@ -1,12 +1,10 @@
 package Tie::NormalArray;
 
-# $Id: NormalArray.pm 1049 2003-12-08 21:10:33Z jonasbn $
-
 use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 sub TIEARRAY {
     my ($class, $shadow) = @_;
@@ -65,3 +63,44 @@ sub STORESIZE {
 
 1;
 
+__END__
+
+=head1 NAME
+
+Tie::NormalArray
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 SUBROUTINES/METHODS
+
+=head2 TIEARRAY
+
+=head2 FETCH
+
+=head2 STORE
+
+=head2 DESTROY
+
+=head2 size
+
+=head2 FETCHSIZE
+
+=head2 STORESIZE
+
+=head1 AUTHOR
+
+Ariel Brosh, schop@cpan.org.
+B<Tie::Cache> was written by Joshua Chamas, chamas@alumni.stanford.org
+
+=head1 SEE ALSO
+
+perl(1), L<Tie::Cache>.
+
+=head1 COPYRIGHT
+
+Tie::Collection is part of the HTPL package. See L<HTML::HTPL>
+
+=cut
+
