@@ -1,16 +1,24 @@
 package Tie::Tools;
 
-# $Id: Tools.pm 1884 2007-10-29 21:25:10Z jonasbn $
-
 use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 1;
 
-__END__;
+__END__
+
+=pod
+
+=begin markdown
+
+[![CPAN version](https://badge.fury.io/pl/Tie-Tools.svg)](http://badge.fury.io/pl/Tie-Tools)
+[![Build Status](https://travis-ci.org/jonasbn/Tie-Tools.svg?branch=master)](https://travis-ci.org/jonasbn/Tie-Tools)
+[![Coverage Status](https://coveralls.io/repos/jonasbn/Tie-Tools/badge.png)](https://coveralls.io/r/jonasbn/Tie-Tools)
+
+=end markdown
 
 =head1 NAME
 
@@ -22,31 +30,21 @@ Tie::Tools consist of several modules each in their own namespace.
 
 =over 4
 
-=item
+=item * L<Tie::DeepTied>
 
-Tie::DeepTied
+=item * L<Tie::Depth>
 
-=item
+=item * L<Tie::Func>
 
-Tie::Depth
+=item * L<Tie::NormalArray>
 
-=item
-
-Tie::Func
-
-=item
-
-Tie::NormalArray
-
-=item
-
-Tie::Parent
+=item * L<Tie::Parent>
 
 =back
 
 =cut
 
-=head1 COPYRIGHT
+=head1 LICENSE
 
 Tie::Tools is free software and is released under the Artistic License.
 See <http://www.perl.com/language/misc/Artistic.html> for details.
@@ -66,6 +64,10 @@ Jonas B. Nielsen <jonasbn@cpan.org>
 
 =head1 ACKNOWLEDGEMENTS
 
-- patch from Brian Dowling resulting in release 1.06
+=over
+
+=item * patch from Brian Dowling resulting in release 1.06
+
+=back
 
 =cut
